#include <Arduino.h>
#include <Crypto.h>
#include <DFRobot_ID809.h>
#include <EEPROM.h>

// use serial3 as interface with fingerprint
// sensor.

#define FPSerial Serial3

// define buillt_in led

#define BUILTIN_LED 13

// Collect the fingerprint 3 times

#define COLLECT_NUMBER 3

/*------Global variables--------------*/

DFRobot_ID809 fingerprint;
uint8_t ID, i, ret;
uint8_t data[25600];
/*-----Blink on board led -------------- */

void blink_led() {
  digitalWrite(BUILTIN_LED, HIGH);
  delay(500);
  digitalWrite(BUILTIN_LED, LOW);
  delay(500);
}

/*--------- Send raw data to serial port----*/

void serialPrintFPdata() {
  for (uint16_t i = 0; i < 25600; i++) {
    // Serial.print(i);
    // Serial.print('\t');
    Serial.print(data[i]);
    Serial.print(" ");
    delay(10);
  }
  // Serial.println();
  // Serial.flush();
}

/*----- Read fingerpritn image data ------*/
void read_image() {

  // Full image of fingerprint
  // uint8_t data[25600] = {0};

  /*Set the fingerprint module LED ring to blue breathing lighting effect*/
  fingerprint.ctrlLED(/*LEDMode = */ fingerprint.eBreathing,
                      /*LEDColor = */ fingerprint.eLEDBlue,
                      /*blinkCount = */ 0);
  // Serial.println("Please release your finger");
  // Collect full images
  fingerprint.getFingerImage(data);
  delay(100);
}

/*---------Arduino setup function------*/

void setup() {
  // config led_pin as output
  pinMode(BUILTIN_LED, OUTPUT);
  // use serial port to print the baud rate
  Serial.begin(9600);
  // config fingerprint sensor
  FPSerial.begin(115200);
  fingerprint.begin(FPSerial);

  while (fingerprint.isConnected() == false) {
    Serial.println("Communication with the device failed");
    delay(1000);
  }
}

/*-----------Arduino loop function--------- */

void loop() {

  /*Wait for finger to release
Return 1 when finger is detected, otherwise return 0
*/
  while (!fingerprint.detectFinger()) {
    blink_led();
  }

  read_image();
  serialPrintFPdata();
}
